%
% function Pendel_1( w0, v0, tm )
%    Pendel-Schwingung, vollständig
%       w0 : Anfangswinkel in Radiant
%       v0 : Anfangswinkelgeschwindigkeit
%       tm : Länge des Zeitintervalls in Sekunden
%
%       Beispiel-Aufrufe: 
%          Pendel_1( 0.1, 0, 10 ) - sinus-ähnlich
%          Pendel_1( 2.8, 0, 10 ) - noch periodisch, andere Frequenz
%          Pendel_1( 2.8, -2, 3 ) - durchschlagend
%
%    zugehörige DGL-Funktion: Pendel_1_Fun.m
%
function  Pendel_1( w0, v0, tm )

   % Pendel-Konstanten
   L = 0.5;   % Fadenlänge, 0.5 m, 
   g = 9.81;  % 9.81 m/s2: Erdbeschleunigung
   
   % Kreisfreq^2
   gVar = g / L;
   
   % Anfangswerte
   y0 = [ w0, v0 ];
   % Zeit-Intervall
   tspan = [0,tm];
   
   % Lösung des Anfangswert-Problems
   [t,y] = ode45( @Pendel_1_Fun, tspan, y0,[], gVar );
   % daraus den Funktionswert - 1. Komponente
   z = y( :, 1 );
    
   % alles plotten
   plot( t, z );
   grid on; 
end  